@@ -329,18 +329,13 @@ impl IncludeCppConfig {
                     .chain(self.pod_requests.iter())
                     .cloned()
                     .chain(self.active_utilities())
-                    .chain(
-                        self.subclasses
-                            .iter()
-                            .map(|sc| {
-                                [
-                                    format!("{}Cpp", sc.subclass),
-                                    sc.subclass.to_string(), // TODO may not be necessary
-                                    sc.superclass.clone(),
-                                ]
-                            })
-                            .flatten(),
-                    ),
+                    .chain(self.subclasses.iter().flat_map(|sc| {
+                        [
+                            format!("{}Cpp", sc.subclass),
+                            sc.subclass.to_string(), // TODO may not be necessary
+                            sc.superclass.clone(),
+                        ]
+                    })),
             )),
             Allowlist::Unspecified(_) => unreachable!(),
         }
@@ -416,13 +411,13 @@ impl IncludeCppConfig {
     pub fn is_subclass_holder(&self, id: &str) -> bool {
         self.subclasses
             .iter()
-            .any(|sc| format!("{}Holder", sc.subclass.to_string()) == id)
+            .any(|sc| format!("{}Holder", sc.subclass) == id)
     }
 
     fn is_subclass_cpp(&self, id: &str) -> bool {
         self.subclasses
             .iter()
-            .any(|sc| format!("{}Cpp", sc.subclass.to_string()) == id)
+            .any(|sc| format!("{}Cpp", sc.subclass) == id)
     }
 
     /// Return the filename to which generated .rs should be written.
